@@ -131,8 +131,12 @@ class Gui(abstract.Gui):
         self.setup_statisticsviewer(
            statisticsviewer.PercentagesStatisticsViewer, _("Sing interval"))
     def _new_question(self):
-        r = self.m_t.new_question(self.get_string('user/lowest_pitch'),
-                                  self.get_string('user/highest_pitch'))
+        try:
+            r = self.m_t.new_question(self.get_string('user/lowest_pitch'),
+                                      self.get_string('user/highest_pitch'))
+        except Teacher.ConfigureException, e:
+            solfege.win.display_error_message2(_("Exercise configuration problem"), unicode(e))
+            return
         if r == Teacher.OK:
             self.m_t.play_first_tone()
             self.g_score_displayer.display_score(self.m_t.get_question())
